==> react-image-annotate_ns_demo-4.0.51.tgz: package/LazyBrush/BrushKeyFrame.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import Brush from "@mui/icons-material/Brush";
import TrashIcon from "@mui/icons-material/Delete";
import * as colors from "@mui/material/colors";
import { createTheme, styled, ThemeProvider } from "@mui/material/styles";
import React from "react";
import getTimeString from "../KeyframeTimeline/get-time-string";
import SidebarBoxContainer from "../SidebarBoxContainer";
var theme = createTheme();
var KeyframeRow = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {
    cursor: "pointer",
    display: "flex",
    alignItems: "center",
    padding: 8,
    fontSize: 14,
    color: colors.grey[700],
    "&.current": {
      backgroundColor: colors.blue[100]
    },
    "&:hover": {
      backgroundColor: colors.grey[100]
    },
    "& .time": {
      flexGrow: 1,
      fontWeight: "bold",
      "& .regionCount": {
        marginLeft: 8,
        fontWeight: "normal",
        color: colors.grey[500]
      }
    },
    "& .trash": {
      "& .icon": {
        fontSize: 18,
        color: colors.grey[600],
        transition: "transform 80ms",
        "&:hover": {
          color: colors.grey[800],
          transform: "scale(1.25,1.25)"
        }
      }
    }
  };
});

var BrushKeyFrame = function BrushKeyFrame(_ref2) {
  var currentVideoTime = _ref2.currentVideoTime,
      setdelete_annotation = _ref2.setdelete_annotation,
      onChangeVideoTime = _ref2.onChangeVideoTime,
      setLines = _ref2.setLines,
      brushLines = _ref2.brushLines,
      delete_annotation = _ref2.delete_annotation;
  //   const keyframeTimes = brushLines
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "Brush Keyframes",
    subTitle: "",
    icon: /*#__PURE__*/React.createElement(Brush, {
      style: {
        color: colors.grey[700]
      }
    }),
    expandedByDefault: true
  }, brushLines.map(function (t, index) {
    return /*#__PURE__*/React.createElement(KeyframeRow, {
      fullWidth: true,
      key: t,
      className: currentVideoTime === t.keyframes.keyframes ? "current" : "",
      onClick: function onClick() {
        return onChangeVideoTime(t.keyframes);
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "time"
    }, getTimeString(t.keyframes, 2), /*#__PURE__*/React.createElement("span", {
      className: "regionCount"
    }, "(", t.tool, ")")), /*#__PURE__*/React.createElement("div", {
      className: "trash"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(brushLines);

        linessave.splice(index, 1);
        brushLines = linessave;
        setLines(linessave);

        var arr = _toConsumableArray(delete_annotation);

        arr.push(t);
        setdelete_annotation(arr);
        e.stopPropagation();
      },
      className: "icon"
    })));
  })));
};

export default BrushKeyFrame;

==> react-image-annotate_ns_demo-4.0.70.tgz: package/LazyBrush/BrushKeyFrame.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import Brush from "@mui/icons-material/Brush";
import TrashIcon from "@mui/icons-material/Delete";
import * as colors from "@mui/material/colors";
import { createTheme, styled, ThemeProvider } from "@mui/material/styles";
import React from "react";
import getTimeString from "../KeyframeTimeline/get-time-string";
import SidebarBoxContainer from "../SidebarBoxContainer";
var theme = createTheme();
var KeyframeRow = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {
    cursor: "pointer",
    display: "flex",
    alignItems: "center",
    padding: 8,
    fontSize: 14,
    color: colors.grey[700],
    "&.current": {
      backgroundColor: colors.blue[100]
    },
    "&:hover": {
      backgroundColor: colors.grey[100]
    },
    "& .time": {
      flexGrow: 1,
      fontWeight: "bold",
      "& .regionCount": {
        marginLeft: 8,
        fontWeight: "normal",
        color: colors.grey[500]
      }
    },
    "& .trash": {
      "& .icon": {
        fontSize: 18,
        color: colors.grey[600],
        transition: "transform 80ms",
        "&:hover": {
          color: colors.grey[800],
          transform: "scale(1.25,1.25)"
        }
      }
    }
  };
});

var BrushKeyFrame = function BrushKeyFrame(_ref2) {
  var currentVideoTime = _ref2.currentVideoTime,
      setdelete_annotation = _ref2.setdelete_annotation,
      onChangeVideoTime = _ref2.onChangeVideoTime,
      setLines = _ref2.setLines,
      brushLines = _ref2.brushLines,
      delete_annotation = _ref2.delete_annotation;
  //   const keyframeTimes = brushLines
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "Brush Keyframes",
    subTitle: "",
    icon: /*#__PURE__*/React.createElement(Brush, {
      style: {
        color: colors.grey[700]
      }
    }),
    expandedByDefault: true
  }, brushLines.map(function (t, index) {
    return /*#__PURE__*/React.createElement(KeyframeRow, {
      fullWidth: true,
      key: t,
      className: currentVideoTime === (t === null || t === void 0 ? void 0 : t.keyframes) ? "current" : "",
      onClick: function onClick() {
        return onChangeVideoTime(t === null || t === void 0 ? void 0 : t.keyframes);
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "time"
    }, getTimeString(t === null || t === void 0 ? void 0 : t.keyframes, 2), /*#__PURE__*/React.createElement("span", {
      className: "regionCount"
    }, "(", t.tool, ")")), /*#__PURE__*/React.createElement("div", {
      className: "trash"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(brushLines);

        linessave.splice(index, 1);
        brushLines = linessave;
        setLines(linessave);

        var arr = _toConsumableArray(delete_annotation);

        arr.push(t);
        setdelete_annotation(arr);
        e.stopPropagation();
      },
      className: "icon"
    })));
  })));
};

export default BrushKeyFrame;
